@@ -3,18 +3,21 @@ from anndata import AnnData
 from .._compat import Literal
 from PIL import Image
 from pathlib import Path
+
 # Test progress bar
 from tqdm import tqdm
 import numpy as np
+import os
+
 
 def tiling(
-        adata: AnnData,
-        out_path: Union[Path, str] = "./",
-        library_id: str = None,
-        crop_size: int = 40,
-        target_size: int = 299,
-        verbose: bool = False,
-        copy: bool = False
+    adata: AnnData,
+    out_path: Union[Path, str] = "./tiling",
+    library_id: str = None,
+    crop_size: int = 40,
+    target_size: int = 299,
+    verbose: bool = False,
+    copy: bool = False,
 ) -> Optional[AnnData]:
     """\
     Tiling H&E images to small tiles based on spot spatial location
@@ -45,29 +48,41 @@ def tiling(
     if library_id is None:
         library_id = list(adata.uns["spatial"].keys())[0]
 
-    image = (adata.uns["spatial"][library_id]["images"][adata.uns["spatial"]["use_quality"]]* 255).astype(np.uint8)
+    # Check the exist of out_path
+    if not os.path.isdir(out_path):
+        os.mkdir(out_path)
 
+    image = adata.uns["spatial"][library_id]["images"][adata.uns["spatial"]["use_quality"]]
+    if image.dtype == np.float32 or image.dtype == np.float64:
+        image = (image * 255).astype(np.uint8)
     img_pillow = Image.fromarray(image)
     tile_names = []
 
-    with tqdm(total=len(adata), desc="Tiling image", bar_format="{l_bar}{bar} [ time left: {remaining} ]") as pbar:
+    with tqdm(
+        total=len(adata),
+        desc="Tiling image",
+        bar_format="{l_bar}{bar} [ time left: {remaining} ]",
+    ) as pbar:
         for imagerow, imagecol in zip(adata.obs["imagerow"], adata.obs["imagecol"]):
             imagerow_down = imagerow - crop_size / 2
             imagerow_up = imagerow + crop_size / 2
             imagecol_left = imagecol - crop_size / 2
             imagecol_right = imagecol + crop_size / 2
             tile = img_pillow.crop(
-                (imagecol_left, imagerow_down, imagecol_right, imagerow_up))
+                (imagecol_left, imagerow_down, imagecol_right, imagerow_up)
+            )
             tile.thumbnail((target_size, target_size), Image.ANTIALIAS)
             tile.resize((target_size, target_size))
-            tile_name = str(imagecol) + '-' + str(imagerow) + \
-                '-' + str(crop_size)
-            out_tile = Path(out_path) / (tile_name + '.jpeg')
+            tile_name = str(imagecol) + "-" + str(imagerow) + "-" + str(crop_size)
+            out_tile = Path(out_path) / (tile_name + ".jpeg")
             tile_names.append(str(out_tile))
             if verbose:
-                print("generate tile at location ({}, {})".format(
-                    str(imagecol), str(imagerow)))
-            tile.save(out_tile, 'JPEG')
+                print(
+                    "generate tile at location ({}, {})".format(
+                        str(imagecol), str(imagerow)
+                    )
+                )
+            tile.save(out_tile, "JPEG")
 
             pbar.update(1)
 
