@@ -18,23 +18,38 @@ class Model:
 
     def load_model(self):
         if self.base == "resnet50":
-            from tensorflow.keras.applications.resnet50 import ResNet50, preprocess_input
+            from tensorflow.keras.applications.resnet50 import (
+                ResNet50,
+                preprocess_input,
+            )
+
             cnn_base_model = ResNet50(
-                include_top=False, weights='imagenet', pooling="avg")
+                include_top=False, weights="imagenet", pooling="avg"
+            )
         elif self.base == "vgg16":
             from tensorflow.keras.applications.vgg16 import VGG16, preprocess_input
-            cnn_base_model = VGG16(
-                include_top=False, weights='imagenet', pooling="avg")
+
+            cnn_base_model = VGG16(include_top=False, weights="imagenet", pooling="avg")
         elif self.base == "inception_v3":
-            from tensorflow.keras.applications.inception_v3 import InceptionV3, preprocess_input
+            from tensorflow.keras.applications.inception_v3 import (
+                InceptionV3,
+                preprocess_input,
+            )
+
             cnn_base_model = InceptionV3(
-                include_top=False, weights='imagenet', pooling="avg")
+                include_top=False, weights="imagenet", pooling="avg"
+            )
         elif self.base == "xception":
-            from tensorflow.keras.applications.xception import Xception, preprocess_input
+            from tensorflow.keras.applications.xception import (
+                Xception,
+                preprocess_input,
+            )
+
             cnn_base_model = Xception(
-                include_top=False, weights='imagenet', pooling="avg")
+                include_top=False, weights="imagenet", pooling="avg"
+            )
         else:
-            raise ValueError('{} is not a valid model'.format(self.base))
+            raise ValueError("{} is not a valid model".format(self.base))
         return cnn_base_model, preprocess_input
 
     def predict(self, x):
