@@ -7,5 +7,5 @@ from .plotting.deconvolution_plot import deconvolution_plot
 from .plotting import trajectory
 from .plotting.QC_plot import QC_plot
 from .plotting.cci_plot import het_plot
-from .plotting.cci_plot import violin_plot
-from .plotting.cci_plot import stacked_bar_plot
+from .plotting.cci_plot import grid_plot
+from .plotting.mask_plot import plot_mask
\ No newline at end of file
